# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ApplicationAppRoleInitArgs', 'ApplicationAppRole']

@pulumi.input_type
class ApplicationAppRoleInitArgs:
    def __init__(__self__, *,
                 allowed_member_types: pulumi.Input[Sequence[pulumi.Input[str]]],
                 application_id: pulumi.Input[str],
                 description: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 role_id: pulumi.Input[str],
                 value: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ApplicationAppRole resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_member_types: A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] description: Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        :param pulumi.Input[str] display_name: Display name for the app role that appears during app role assignment and in consent experiences.
        :param pulumi.Input[str] role_id: The unique identifier of the app role
        :param pulumi.Input[str] value: The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.
               
               > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        pulumi.set(__self__, "allowed_member_types", allowed_member_types)
        pulumi.set(__self__, "application_id", application_id)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "role_id", role_id)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="allowedMemberTypes")
    def allowed_member_types(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        """
        return pulumi.get(self, "allowed_member_types")

    @allowed_member_types.setter
    def allowed_member_types(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "allowed_member_types", value)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Input[str]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        Display name for the app role that appears during app role assignment and in consent experiences.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Input[str]:
        """
        The unique identifier of the app role
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.

        > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _ApplicationAppRoleState:
    def __init__(__self__, *,
                 allowed_member_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ApplicationAppRole resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_member_types: A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] description: Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        :param pulumi.Input[str] display_name: Display name for the app role that appears during app role assignment and in consent experiences.
        :param pulumi.Input[str] role_id: The unique identifier of the app role
        :param pulumi.Input[str] value: The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.
               
               > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        if allowed_member_types is not None:
            pulumi.set(__self__, "allowed_member_types", allowed_member_types)
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="allowedMemberTypes")
    def allowed_member_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        """
        return pulumi.get(self, "allowed_member_types")

    @allowed_member_types.setter
    def allowed_member_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_member_types", value)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Display name for the app role that appears during app role assignment and in consent experiences.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[str]]:
        """
        The unique identifier of the app role
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.

        > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


class ApplicationAppRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_member_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread
        import pulumi_random as random

        example = azuread.ApplicationRegistration("example", display_name="example")
        example_administrator = random.RandomUuid("example_administrator")
        example_administer = azuread.ApplicationAppRole("example_administer",
            application_id=example.id,
            role_id=example_administrator.id,
            allowed_member_types=["User"],
            description="My role description",
            display_name="Administer",
            value="admin")
        ```

        > **Tip** For managing more app roles, create additional instances of this resource

        *Usage with Application resource*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Application("example", display_name="example")
        example_administer = azuread.ApplicationAppRole("example_administer", application_id=example.id)
        ```

        ## Import

        Application App Roles can be imported using the object ID of the application and the ID of the app role, in the following format.

        ```sh
        $ pulumi import azuread:index/applicationAppRole:ApplicationAppRole example /applications/00000000-0000-0000-0000-000000000000/appRoles/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_member_types: A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] description: Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        :param pulumi.Input[str] display_name: Display name for the app role that appears during app role assignment and in consent experiences.
        :param pulumi.Input[str] role_id: The unique identifier of the app role
        :param pulumi.Input[str] value: The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.
               
               > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationAppRoleInitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread
        import pulumi_random as random

        example = azuread.ApplicationRegistration("example", display_name="example")
        example_administrator = random.RandomUuid("example_administrator")
        example_administer = azuread.ApplicationAppRole("example_administer",
            application_id=example.id,
            role_id=example_administrator.id,
            allowed_member_types=["User"],
            description="My role description",
            display_name="Administer",
            value="admin")
        ```

        > **Tip** For managing more app roles, create additional instances of this resource

        *Usage with Application resource*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Application("example", display_name="example")
        example_administer = azuread.ApplicationAppRole("example_administer", application_id=example.id)
        ```

        ## Import

        Application App Roles can be imported using the object ID of the application and the ID of the app role, in the following format.

        ```sh
        $ pulumi import azuread:index/applicationAppRole:ApplicationAppRole example /applications/00000000-0000-0000-0000-000000000000/appRoles/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationAppRoleInitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationAppRoleInitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_member_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationAppRoleInitArgs.__new__(ApplicationAppRoleInitArgs)

            if allowed_member_types is None and not opts.urn:
                raise TypeError("Missing required property 'allowed_member_types'")
            __props__.__dict__["allowed_member_types"] = allowed_member_types
            if application_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_id'")
            __props__.__dict__["application_id"] = application_id
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if role_id is None and not opts.urn:
                raise TypeError("Missing required property 'role_id'")
            __props__.__dict__["role_id"] = role_id
            __props__.__dict__["value"] = value
        super(ApplicationAppRole, __self__).__init__(
            'azuread:index/applicationAppRole:ApplicationAppRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_member_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            application_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            role_id: Optional[pulumi.Input[str]] = None,
            value: Optional[pulumi.Input[str]] = None) -> 'ApplicationAppRole':
        """
        Get an existing ApplicationAppRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_member_types: A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] description: Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        :param pulumi.Input[str] display_name: Display name for the app role that appears during app role assignment and in consent experiences.
        :param pulumi.Input[str] role_id: The unique identifier of the app role
        :param pulumi.Input[str] value: The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.
               
               > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationAppRoleState.__new__(_ApplicationAppRoleState)

        __props__.__dict__["allowed_member_types"] = allowed_member_types
        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["value"] = value
        return ApplicationAppRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedMemberTypes")
    def allowed_member_types(self) -> pulumi.Output[Sequence[str]]:
        """
        A set of values to specify whether this app role definition can be assigned to users and groups by setting to `User`, or to other applications by setting to `Application`, or to both.
        """
        return pulumi.get(self, "allowed_member_types")

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[str]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the app role that appears when the role is being assigned, and if the role functions as an application permissions, during the consent experiences.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        Display name for the app role that appears during app role assignment and in consent experiences.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[str]:
        """
        The unique identifier of the app role
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[str]]:
        """
        The value that is used for the `roles` claim in ID tokens and OAuth 2.0 access tokens that are authenticating an assigned service or user principal.

        > **Roles and Permission Scopes** In Azure Active Directory, application roles and permission scopes exported by an application share the same namespace and cannot contain duplicate values.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AuthenticationStrengthPolicyArgs', 'AuthenticationStrengthPolicy']

@pulumi.input_type
class AuthenticationStrengthPolicyArgs:
    def __init__(__self__, *,
                 allowed_combinations: pulumi.Input[Sequence[pulumi.Input[str]]],
                 display_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AuthenticationStrengthPolicy resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_combinations: List of allowed authentication methods for this authentication strength policy.
        :param pulumi.Input[str] display_name: The friendly name for this authentication strength policy.
        :param pulumi.Input[str] description: The description for this authentication strength policy.
        """
        pulumi.set(__self__, "allowed_combinations", allowed_combinations)
        pulumi.set(__self__, "display_name", display_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="allowedCombinations")
    def allowed_combinations(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of allowed authentication methods for this authentication strength policy.
        """
        return pulumi.get(self, "allowed_combinations")

    @allowed_combinations.setter
    def allowed_combinations(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "allowed_combinations", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        The friendly name for this authentication strength policy.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description for this authentication strength policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _AuthenticationStrengthPolicyState:
    def __init__(__self__, *,
                 allowed_combinations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AuthenticationStrengthPolicy resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_combinations: List of allowed authentication methods for this authentication strength policy.
        :param pulumi.Input[str] description: The description for this authentication strength policy.
        :param pulumi.Input[str] display_name: The friendly name for this authentication strength policy.
        """
        if allowed_combinations is not None:
            pulumi.set(__self__, "allowed_combinations", allowed_combinations)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)

    @property
    @pulumi.getter(name="allowedCombinations")
    def allowed_combinations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of allowed authentication methods for this authentication strength policy.
        """
        return pulumi.get(self, "allowed_combinations")

    @allowed_combinations.setter
    def allowed_combinations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "allowed_combinations", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description for this authentication strength policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The friendly name for this authentication strength policy.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)


class AuthenticationStrengthPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_combinations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Authentication Strength Policy within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the following application roles: `Policy.ReadWrite.ConditionalAccess` and `Policy.Read.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Conditional Access Administrator` or `Global Administrator`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.AuthenticationStrengthPolicy("example",
            display_name="Example Authentication Strength Policy",
            description="Policy for demo purposes",
            allowed_combinations=[
                "fido2",
                "password",
            ])
        example2 = azuread.AuthenticationStrengthPolicy("example2",
            display_name="Example Authentication Strength Policy",
            description="Policy for demo purposes with all possible combinations",
            allowed_combinations=[
                "fido2",
                "password",
                "deviceBasedPush",
                "temporaryAccessPassOneTime",
                "federatedMultiFactor",
                "federatedSingleFactor",
                "hardwareOath,federatedSingleFactor",
                "microsoftAuthenticatorPush,federatedSingleFactor",
                "password,hardwareOath",
                "password,microsoftAuthenticatorPush",
                "password,sms",
                "password,softwareOath",
                "password,voice",
                "sms",
                "sms,federatedSingleFactor",
                "softwareOath,federatedSingleFactor",
                "temporaryAccessPassMultiUse",
                "voice,federatedSingleFactor",
                "windowsHelloForBusiness",
                "x509CertificateMultiFactor",
                "x509CertificateSingleFactor",
            ])
        ```

        ## Import

        Authentication Strength Policies can be imported using the `id`, e.g.

        ```sh
        $ pulumi import azuread:index/authenticationStrengthPolicy:AuthenticationStrengthPolicy my_policy /policies/authenticationStrengthPolicies/00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_combinations: List of allowed authentication methods for this authentication strength policy.
        :param pulumi.Input[str] description: The description for this authentication strength policy.
        :param pulumi.Input[str] display_name: The friendly name for this authentication strength policy.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthenticationStrengthPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Authentication Strength Policy within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the following application roles: `Policy.ReadWrite.ConditionalAccess` and `Policy.Read.All`

        When authenticated with a user principal, this resource requires one of the following directory roles: `Conditional Access Administrator` or `Global Administrator`

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.AuthenticationStrengthPolicy("example",
            display_name="Example Authentication Strength Policy",
            description="Policy for demo purposes",
            allowed_combinations=[
                "fido2",
                "password",
            ])
        example2 = azuread.AuthenticationStrengthPolicy("example2",
            display_name="Example Authentication Strength Policy",
            description="Policy for demo purposes with all possible combinations",
            allowed_combinations=[
                "fido2",
                "password",
                "deviceBasedPush",
                "temporaryAccessPassOneTime",
                "federatedMultiFactor",
                "federatedSingleFactor",
                "hardwareOath,federatedSingleFactor",
                "microsoftAuthenticatorPush,federatedSingleFactor",
                "password,hardwareOath",
                "password,microsoftAuthenticatorPush",
                "password,sms",
                "password,softwareOath",
                "password,voice",
                "sms",
                "sms,federatedSingleFactor",
                "softwareOath,federatedSingleFactor",
                "temporaryAccessPassMultiUse",
                "voice,federatedSingleFactor",
                "windowsHelloForBusiness",
                "x509CertificateMultiFactor",
                "x509CertificateSingleFactor",
            ])
        ```

        ## Import

        Authentication Strength Policies can be imported using the `id`, e.g.

        ```sh
        $ pulumi import azuread:index/authenticationStrengthPolicy:AuthenticationStrengthPolicy my_policy /policies/authenticationStrengthPolicies/00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param AuthenticationStrengthPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthenticationStrengthPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_combinations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthenticationStrengthPolicyArgs.__new__(AuthenticationStrengthPolicyArgs)

            if allowed_combinations is None and not opts.urn:
                raise TypeError("Missing required property 'allowed_combinations'")
            __props__.__dict__["allowed_combinations"] = allowed_combinations
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
        super(AuthenticationStrengthPolicy, __self__).__init__(
            'azuread:index/authenticationStrengthPolicy:AuthenticationStrengthPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_combinations: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None) -> 'AuthenticationStrengthPolicy':
        """
        Get an existing AuthenticationStrengthPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] allowed_combinations: List of allowed authentication methods for this authentication strength policy.
        :param pulumi.Input[str] description: The description for this authentication strength policy.
        :param pulumi.Input[str] display_name: The friendly name for this authentication strength policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthenticationStrengthPolicyState.__new__(_AuthenticationStrengthPolicyState)

        __props__.__dict__["allowed_combinations"] = allowed_combinations
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        return AuthenticationStrengthPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedCombinations")
    def allowed_combinations(self) -> pulumi.Output[Sequence[str]]:
        """
        List of allowed authentication methods for this authentication strength policy.
        """
        return pulumi.get(self, "allowed_combinations")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description for this authentication strength policy.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The friendly name for this authentication strength policy.
        """
        return pulumi.get(self, "display_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupRoleManagementPolicyArgs', 'GroupRoleManagementPolicy']

@pulumi.input_type
class GroupRoleManagementPolicyArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[str],
                 role_id: pulumi.Input[str],
                 activation_rules: Optional[pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs']] = None,
                 active_assignment_rules: Optional[pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs']] = None,
                 eligible_assignment_rules: Optional[pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs']] = None,
                 notification_rules: Optional[pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs']] = None):
        """
        The set of arguments for constructing a GroupRoleManagementPolicy resource.
        :param pulumi.Input[str] group_id: The ID of the Azure AD group for which the policy applies.
        :param pulumi.Input[str] role_id: The type of assignment this policy coveres. Can be either `member` or `owner`.
        :param pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs'] activation_rules: An `activation_rules` block as defined below.
        :param pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs'] active_assignment_rules: An `active_assignment_rules` block as defined below.
        :param pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs'] eligible_assignment_rules: An `eligible_assignment_rules` block as defined below.
        :param pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs'] notification_rules: A `notification_rules` block as defined below.
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "role_id", role_id)
        if activation_rules is not None:
            pulumi.set(__self__, "activation_rules", activation_rules)
        if active_assignment_rules is not None:
            pulumi.set(__self__, "active_assignment_rules", active_assignment_rules)
        if eligible_assignment_rules is not None:
            pulumi.set(__self__, "eligible_assignment_rules", eligible_assignment_rules)
        if notification_rules is not None:
            pulumi.set(__self__, "notification_rules", notification_rules)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The ID of the Azure AD group for which the policy applies.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Input[str]:
        """
        The type of assignment this policy coveres. Can be either `member` or `owner`.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="activationRules")
    def activation_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs']]:
        """
        An `activation_rules` block as defined below.
        """
        return pulumi.get(self, "activation_rules")

    @activation_rules.setter
    def activation_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs']]):
        pulumi.set(self, "activation_rules", value)

    @property
    @pulumi.getter(name="activeAssignmentRules")
    def active_assignment_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs']]:
        """
        An `active_assignment_rules` block as defined below.
        """
        return pulumi.get(self, "active_assignment_rules")

    @active_assignment_rules.setter
    def active_assignment_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs']]):
        pulumi.set(self, "active_assignment_rules", value)

    @property
    @pulumi.getter(name="eligibleAssignmentRules")
    def eligible_assignment_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs']]:
        """
        An `eligible_assignment_rules` block as defined below.
        """
        return pulumi.get(self, "eligible_assignment_rules")

    @eligible_assignment_rules.setter
    def eligible_assignment_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs']]):
        pulumi.set(self, "eligible_assignment_rules", value)

    @property
    @pulumi.getter(name="notificationRules")
    def notification_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs']]:
        """
        A `notification_rules` block as defined below.
        """
        return pulumi.get(self, "notification_rules")

    @notification_rules.setter
    def notification_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs']]):
        pulumi.set(self, "notification_rules", value)


@pulumi.input_type
class _GroupRoleManagementPolicyState:
    def __init__(__self__, *,
                 activation_rules: Optional[pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs']] = None,
                 active_assignment_rules: Optional[pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 eligible_assignment_rules: Optional[pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs']] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 notification_rules: Optional[pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs']] = None,
                 role_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GroupRoleManagementPolicy resources.
        :param pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs'] activation_rules: An `activation_rules` block as defined below.
        :param pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs'] active_assignment_rules: An `active_assignment_rules` block as defined below.
        :param pulumi.Input[str] description: (String) The description of this policy.
        :param pulumi.Input[str] display_name: (String) The display name of this policy.
        :param pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs'] eligible_assignment_rules: An `eligible_assignment_rules` block as defined below.
        :param pulumi.Input[str] group_id: The ID of the Azure AD group for which the policy applies.
        :param pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs'] notification_rules: A `notification_rules` block as defined below.
        :param pulumi.Input[str] role_id: The type of assignment this policy coveres. Can be either `member` or `owner`.
        """
        if activation_rules is not None:
            pulumi.set(__self__, "activation_rules", activation_rules)
        if active_assignment_rules is not None:
            pulumi.set(__self__, "active_assignment_rules", active_assignment_rules)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if eligible_assignment_rules is not None:
            pulumi.set(__self__, "eligible_assignment_rules", eligible_assignment_rules)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if notification_rules is not None:
            pulumi.set(__self__, "notification_rules", notification_rules)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)

    @property
    @pulumi.getter(name="activationRules")
    def activation_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs']]:
        """
        An `activation_rules` block as defined below.
        """
        return pulumi.get(self, "activation_rules")

    @activation_rules.setter
    def activation_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyActivationRulesArgs']]):
        pulumi.set(self, "activation_rules", value)

    @property
    @pulumi.getter(name="activeAssignmentRules")
    def active_assignment_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs']]:
        """
        An `active_assignment_rules` block as defined below.
        """
        return pulumi.get(self, "active_assignment_rules")

    @active_assignment_rules.setter
    def active_assignment_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyActiveAssignmentRulesArgs']]):
        pulumi.set(self, "active_assignment_rules", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (String) The description of this policy.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (String) The display name of this policy.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="eligibleAssignmentRules")
    def eligible_assignment_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs']]:
        """
        An `eligible_assignment_rules` block as defined below.
        """
        return pulumi.get(self, "eligible_assignment_rules")

    @eligible_assignment_rules.setter
    def eligible_assignment_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyEligibleAssignmentRulesArgs']]):
        pulumi.set(self, "eligible_assignment_rules", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Azure AD group for which the policy applies.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="notificationRules")
    def notification_rules(self) -> Optional[pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs']]:
        """
        A `notification_rules` block as defined below.
        """
        return pulumi.get(self, "notification_rules")

    @notification_rules.setter
    def notification_rules(self, value: Optional[pulumi.Input['GroupRoleManagementPolicyNotificationRulesArgs']]):
        pulumi.set(self, "notification_rules", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[str]]:
        """
        The type of assignment this policy coveres. Can be either `member` or `owner`.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_id", value)


class GroupRoleManagementPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 activation_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyActivationRulesArgs', 'GroupRoleManagementPolicyActivationRulesArgsDict']]] = None,
                 active_assignment_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyActiveAssignmentRulesArgs', 'GroupRoleManagementPolicyActiveAssignmentRulesArgsDict']]] = None,
                 eligible_assignment_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyEligibleAssignmentRulesArgs', 'GroupRoleManagementPolicyEligibleAssignmentRulesArgsDict']]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 notification_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyNotificationRulesArgs', 'GroupRoleManagementPolicyNotificationRulesArgsDict']]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manage a role policy for an Azure AD group.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the `RoleManagementPolicy.ReadWrite.AzureADGroup` Microsoft Graph API permissions.

        When authenticated with a user principal, this resource requires `Global Administrator` directory role, or the `Privileged Role Administrator` role in Identity Governance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Group("example",
            display_name="group-name",
            security_enabled=True)
        member = azuread.User("member",
            user_principal_name="jdoe@example.com",
            display_name="J. Doe",
            mail_nickname="jdoe",
            password="SecretP@sswd99!")
        example_group_role_management_policy = azuread.GroupRoleManagementPolicy("example",
            group_id=example.id,
            role_id="member",
            active_assignment_rules={
                "expire_after": "P365D",
            },
            eligible_assignment_rules={
                "expiration_required": False,
            },
            notification_rules={
                "eligible_assignments": {
                    "approver_notifications": {
                        "notification_level": "Critical",
                        "default_recipients": False,
                        "additional_recipients": [
                            "someone@example.com",
                            "someone.else@example.com",
                        ],
                    },
                },
            })
        ```

        ## Import

        Because these policies are created automatically by Entra ID, they will auto-import on first use.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GroupRoleManagementPolicyActivationRulesArgs', 'GroupRoleManagementPolicyActivationRulesArgsDict']] activation_rules: An `activation_rules` block as defined below.
        :param pulumi.Input[Union['GroupRoleManagementPolicyActiveAssignmentRulesArgs', 'GroupRoleManagementPolicyActiveAssignmentRulesArgsDict']] active_assignment_rules: An `active_assignment_rules` block as defined below.
        :param pulumi.Input[Union['GroupRoleManagementPolicyEligibleAssignmentRulesArgs', 'GroupRoleManagementPolicyEligibleAssignmentRulesArgsDict']] eligible_assignment_rules: An `eligible_assignment_rules` block as defined below.
        :param pulumi.Input[str] group_id: The ID of the Azure AD group for which the policy applies.
        :param pulumi.Input[Union['GroupRoleManagementPolicyNotificationRulesArgs', 'GroupRoleManagementPolicyNotificationRulesArgsDict']] notification_rules: A `notification_rules` block as defined below.
        :param pulumi.Input[str] role_id: The type of assignment this policy coveres. Can be either `member` or `owner`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupRoleManagementPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage a role policy for an Azure AD group.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires the `RoleManagementPolicy.ReadWrite.AzureADGroup` Microsoft Graph API permissions.

        When authenticated with a user principal, this resource requires `Global Administrator` directory role, or the `Privileged Role Administrator` role in Identity Governance.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.Group("example",
            display_name="group-name",
            security_enabled=True)
        member = azuread.User("member",
            user_principal_name="jdoe@example.com",
            display_name="J. Doe",
            mail_nickname="jdoe",
            password="SecretP@sswd99!")
        example_group_role_management_policy = azuread.GroupRoleManagementPolicy("example",
            group_id=example.id,
            role_id="member",
            active_assignment_rules={
                "expire_after": "P365D",
            },
            eligible_assignment_rules={
                "expiration_required": False,
            },
            notification_rules={
                "eligible_assignments": {
                    "approver_notifications": {
                        "notification_level": "Critical",
                        "default_recipients": False,
                        "additional_recipients": [
                            "someone@example.com",
                            "someone.else@example.com",
                        ],
                    },
                },
            })
        ```

        ## Import

        Because these policies are created automatically by Entra ID, they will auto-import on first use.

        :param str resource_name: The name of the resource.
        :param GroupRoleManagementPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupRoleManagementPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 activation_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyActivationRulesArgs', 'GroupRoleManagementPolicyActivationRulesArgsDict']]] = None,
                 active_assignment_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyActiveAssignmentRulesArgs', 'GroupRoleManagementPolicyActiveAssignmentRulesArgsDict']]] = None,
                 eligible_assignment_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyEligibleAssignmentRulesArgs', 'GroupRoleManagementPolicyEligibleAssignmentRulesArgsDict']]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 notification_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyNotificationRulesArgs', 'GroupRoleManagementPolicyNotificationRulesArgsDict']]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupRoleManagementPolicyArgs.__new__(GroupRoleManagementPolicyArgs)

            __props__.__dict__["activation_rules"] = activation_rules
            __props__.__dict__["active_assignment_rules"] = active_assignment_rules
            __props__.__dict__["eligible_assignment_rules"] = eligible_assignment_rules
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["notification_rules"] = notification_rules
            if role_id is None and not opts.urn:
                raise TypeError("Missing required property 'role_id'")
            __props__.__dict__["role_id"] = role_id
            __props__.__dict__["description"] = None
            __props__.__dict__["display_name"] = None
        super(GroupRoleManagementPolicy, __self__).__init__(
            'azuread:index/groupRoleManagementPolicy:GroupRoleManagementPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            activation_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyActivationRulesArgs', 'GroupRoleManagementPolicyActivationRulesArgsDict']]] = None,
            active_assignment_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyActiveAssignmentRulesArgs', 'GroupRoleManagementPolicyActiveAssignmentRulesArgsDict']]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            eligible_assignment_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyEligibleAssignmentRulesArgs', 'GroupRoleManagementPolicyEligibleAssignmentRulesArgsDict']]] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            notification_rules: Optional[pulumi.Input[Union['GroupRoleManagementPolicyNotificationRulesArgs', 'GroupRoleManagementPolicyNotificationRulesArgsDict']]] = None,
            role_id: Optional[pulumi.Input[str]] = None) -> 'GroupRoleManagementPolicy':
        """
        Get an existing GroupRoleManagementPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['GroupRoleManagementPolicyActivationRulesArgs', 'GroupRoleManagementPolicyActivationRulesArgsDict']] activation_rules: An `activation_rules` block as defined below.
        :param pulumi.Input[Union['GroupRoleManagementPolicyActiveAssignmentRulesArgs', 'GroupRoleManagementPolicyActiveAssignmentRulesArgsDict']] active_assignment_rules: An `active_assignment_rules` block as defined below.
        :param pulumi.Input[str] description: (String) The description of this policy.
        :param pulumi.Input[str] display_name: (String) The display name of this policy.
        :param pulumi.Input[Union['GroupRoleManagementPolicyEligibleAssignmentRulesArgs', 'GroupRoleManagementPolicyEligibleAssignmentRulesArgsDict']] eligible_assignment_rules: An `eligible_assignment_rules` block as defined below.
        :param pulumi.Input[str] group_id: The ID of the Azure AD group for which the policy applies.
        :param pulumi.Input[Union['GroupRoleManagementPolicyNotificationRulesArgs', 'GroupRoleManagementPolicyNotificationRulesArgsDict']] notification_rules: A `notification_rules` block as defined below.
        :param pulumi.Input[str] role_id: The type of assignment this policy coveres. Can be either `member` or `owner`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupRoleManagementPolicyState.__new__(_GroupRoleManagementPolicyState)

        __props__.__dict__["activation_rules"] = activation_rules
        __props__.__dict__["active_assignment_rules"] = active_assignment_rules
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["eligible_assignment_rules"] = eligible_assignment_rules
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["notification_rules"] = notification_rules
        __props__.__dict__["role_id"] = role_id
        return GroupRoleManagementPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="activationRules")
    def activation_rules(self) -> pulumi.Output['outputs.GroupRoleManagementPolicyActivationRules']:
        """
        An `activation_rules` block as defined below.
        """
        return pulumi.get(self, "activation_rules")

    @property
    @pulumi.getter(name="activeAssignmentRules")
    def active_assignment_rules(self) -> pulumi.Output['outputs.GroupRoleManagementPolicyActiveAssignmentRules']:
        """
        An `active_assignment_rules` block as defined below.
        """
        return pulumi.get(self, "active_assignment_rules")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (String) The description of this policy.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (String) The display name of this policy.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="eligibleAssignmentRules")
    def eligible_assignment_rules(self) -> pulumi.Output['outputs.GroupRoleManagementPolicyEligibleAssignmentRules']:
        """
        An `eligible_assignment_rules` block as defined below.
        """
        return pulumi.get(self, "eligible_assignment_rules")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The ID of the Azure AD group for which the policy applies.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="notificationRules")
    def notification_rules(self) -> pulumi.Output['outputs.GroupRoleManagementPolicyNotificationRules']:
        """
        A `notification_rules` block as defined below.
        """
        return pulumi.get(self, "notification_rules")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[str]:
        """
        The type of assignment this policy coveres. Can be either `member` or `owner`.
        """
        return pulumi.get(self, "role_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDirectoryRolesResult',
    'AwaitableGetDirectoryRolesResult',
    'get_directory_roles',
    'get_directory_roles_output',
]

@pulumi.output_type
class GetDirectoryRolesResult:
    """
    A collection of values returned by getDirectoryRoles.
    """
    def __init__(__self__, id=None, object_ids=None, roles=None, template_ids=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if object_ids and not isinstance(object_ids, list):
            raise TypeError("Expected argument 'object_ids' to be a list")
        pulumi.set(__self__, "object_ids", object_ids)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if template_ids and not isinstance(template_ids, list):
            raise TypeError("Expected argument 'template_ids' to be a list")
        pulumi.set(__self__, "template_ids", template_ids)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="objectIds")
    def object_ids(self) -> Sequence[str]:
        """
        The object IDs of the roles.
        """
        return pulumi.get(self, "object_ids")

    @property
    @pulumi.getter
    def roles(self) -> Sequence['outputs.GetDirectoryRolesRoleResult']:
        """
        A list of users. Each `role` object provides the attributes documented below.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="templateIds")
    def template_ids(self) -> Sequence[str]:
        """
        The template IDs of the roles.
        """
        return pulumi.get(self, "template_ids")


class AwaitableGetDirectoryRolesResult(GetDirectoryRolesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDirectoryRolesResult(
            id=self.id,
            object_ids=self.object_ids,
            roles=self.roles,
            template_ids=self.template_ids)


def get_directory_roles(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDirectoryRolesResult:
    """
    Use this data source to access information about activated directory roles within Azure Active Directory.

    ## API Permissions

    The following API permissions are required in order to use this resource.

    When authenticated with a service principal, this resource requires one of the following application roles: `RoleManagement.Read.Directory` or `Directory.Read.All`

    When authenticated with a user principal, this data source does not require any additional roles.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azuread as azuread

    current = azuread.get_directory_roles()
    pulumi.export("roles", current.object_ids)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azuread:index/getDirectoryRoles:getDirectoryRoles', __args__, opts=opts, typ=GetDirectoryRolesResult).value

    return AwaitableGetDirectoryRolesResult(
        id=pulumi.get(__ret__, 'id'),
        object_ids=pulumi.get(__ret__, 'object_ids'),
        roles=pulumi.get(__ret__, 'roles'),
        template_ids=pulumi.get(__ret__, 'template_ids'))
def get_directory_roles_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDirectoryRolesResult]:
    """
    Use this data source to access information about activated directory roles within Azure Active Directory.

    ## API Permissions

    The following API permissions are required in order to use this resource.

    When authenticated with a service principal, this resource requires one of the following application roles: `RoleManagement.Read.Directory` or `Directory.Read.All`

    When authenticated with a user principal, this data source does not require any additional roles.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azuread as azuread

    current = azuread.get_directory_roles()
    pulumi.export("roles", current.object_ids)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azuread:index/getDirectoryRoles:getDirectoryRoles', __args__, opts=opts, typ=GetDirectoryRolesResult)
    return __ret__.apply(lambda __response__: GetDirectoryRolesResult(
        id=pulumi.get(__response__, 'id'),
        object_ids=pulumi.get(__response__, 'object_ids'),
        roles=pulumi.get(__response__, 'roles'),
        template_ids=pulumi.get(__response__, 'template_ids')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .access_package import *
from .access_package_assignment_policy import *
from .access_package_catalog import *
from .access_package_catalog_role_assignment import *
from .access_package_resource_catalog_association import *
from .access_package_resource_package_association import *
from .administrative_unit import *
from .administrative_unit_member import *
from .administrative_unit_role_member import *
from .app_role_assignment import *
from .application import *
from .application_api_access import *
from .application_app_role import *
from .application_certificate import *
from .application_fallback_public_client import *
from .application_federated_identity_credential import *
from .application_from_template import *
from .application_identifier_uri import *
from .application_known_clients import *
from .application_optional_claims import *
from .application_owner import *
from .application_password import *
from .application_permission_scope import *
from .application_pre_authorized import *
from .application_redirect_uris import *
from .application_registration import *
from .authentication_strength_policy import *
from .claims_mapping_policy import *
from .conditional_access_policy import *
from .custom_directory_role import *
from .directory_role import *
from .directory_role_assignment import *
from .directory_role_eligibility_schedule_request import *
from .directory_role_member import *
from .get_access_package import *
from .get_access_package_catalog import *
from .get_access_package_catalog_role import *
from .get_administrative_unit import *
from .get_application import *
from .get_application_published_app_ids import *
from .get_application_template import *
from .get_client_config import *
from .get_directory_object import *
from .get_directory_role_templates import *
from .get_directory_roles import *
from .get_domains import *
from .get_group import *
from .get_group_role_management_policy import *
from .get_groups import *
from .get_named_location import *
from .get_service_principal import *
from .get_service_principals import *
from .get_user import *
from .get_users import *
from .group import *
from .group_member import *
from .group_role_management_policy import *
from .invitation import *
from .named_location import *
from .privileged_access_group_assignment_schedule import *
from .privileged_access_group_eligibility_schedule import *
from .provider import *
from .service_principal import *
from .service_principal_certificate import *
from .service_principal_claims_mapping_policy_assignment import *
from .service_principal_delegated_permission_grant import *
from .service_principal_password import *
from .service_principal_token_signing_certificate import *
from .synchronization_job import *
from .synchronization_job_provision_on_demand import *
from .synchronization_secret import *
from .user import *
from .user_flow_attribute import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azuread.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_azuread.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "azuread",
  "mod": "index/accessPackage",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/accessPackage:AccessPackage": "AccessPackage"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/accessPackageAssignmentPolicy",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/accessPackageAssignmentPolicy:AccessPackageAssignmentPolicy": "AccessPackageAssignmentPolicy"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/accessPackageCatalog",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/accessPackageCatalog:AccessPackageCatalog": "AccessPackageCatalog"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/accessPackageCatalogRoleAssignment",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/accessPackageCatalogRoleAssignment:AccessPackageCatalogRoleAssignment": "AccessPackageCatalogRoleAssignment"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/accessPackageResourceCatalogAssociation",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/accessPackageResourceCatalogAssociation:AccessPackageResourceCatalogAssociation": "AccessPackageResourceCatalogAssociation"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/accessPackageResourcePackageAssociation",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/accessPackageResourcePackageAssociation:AccessPackageResourcePackageAssociation": "AccessPackageResourcePackageAssociation"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/administrativeUnit",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/administrativeUnit:AdministrativeUnit": "AdministrativeUnit"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/administrativeUnitMember",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/administrativeUnitMember:AdministrativeUnitMember": "AdministrativeUnitMember"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/administrativeUnitRoleMember",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/administrativeUnitRoleMember:AdministrativeUnitRoleMember": "AdministrativeUnitRoleMember"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/appRoleAssignment",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/appRoleAssignment:AppRoleAssignment": "AppRoleAssignment"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/application",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/application:Application": "Application"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationApiAccess",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationApiAccess:ApplicationApiAccess": "ApplicationApiAccess"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationAppRole",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationAppRole:ApplicationAppRole": "ApplicationAppRole"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationCertificate",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationCertificate:ApplicationCertificate": "ApplicationCertificate"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationFallbackPublicClient",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationFallbackPublicClient:ApplicationFallbackPublicClient": "ApplicationFallbackPublicClient"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationFederatedIdentityCredential",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationFederatedIdentityCredential:ApplicationFederatedIdentityCredential": "ApplicationFederatedIdentityCredential"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationFromTemplate",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationFromTemplate:ApplicationFromTemplate": "ApplicationFromTemplate"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationIdentifierUri",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationIdentifierUri:ApplicationIdentifierUri": "ApplicationIdentifierUri"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationKnownClients",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationKnownClients:ApplicationKnownClients": "ApplicationKnownClients"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationOptionalClaims",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationOptionalClaims:ApplicationOptionalClaims": "ApplicationOptionalClaims"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationOwner",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationOwner:ApplicationOwner": "ApplicationOwner"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationPassword",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationPassword:ApplicationPassword": "ApplicationPassword"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationPermissionScope",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationPermissionScope:ApplicationPermissionScope": "ApplicationPermissionScope"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationPreAuthorized",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationPreAuthorized:ApplicationPreAuthorized": "ApplicationPreAuthorized"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationRedirectUris",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationRedirectUris:ApplicationRedirectUris": "ApplicationRedirectUris"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/applicationRegistration",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/applicationRegistration:ApplicationRegistration": "ApplicationRegistration"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/authenticationStrengthPolicy",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/authenticationStrengthPolicy:AuthenticationStrengthPolicy": "AuthenticationStrengthPolicy"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/claimsMappingPolicy",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/claimsMappingPolicy:ClaimsMappingPolicy": "ClaimsMappingPolicy"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/conditionalAccessPolicy",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/conditionalAccessPolicy:ConditionalAccessPolicy": "ConditionalAccessPolicy"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/customDirectoryRole",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/customDirectoryRole:CustomDirectoryRole": "CustomDirectoryRole"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/directoryRole",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/directoryRole:DirectoryRole": "DirectoryRole"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/directoryRoleAssignment",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/directoryRoleAssignment:DirectoryRoleAssignment": "DirectoryRoleAssignment"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/directoryRoleEligibilityScheduleRequest",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/directoryRoleEligibilityScheduleRequest:DirectoryRoleEligibilityScheduleRequest": "DirectoryRoleEligibilityScheduleRequest"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/directoryRoleMember",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/directoryRoleMember:DirectoryRoleMember": "DirectoryRoleMember"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/group",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/group:Group": "Group"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/groupMember",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/groupMember:GroupMember": "GroupMember"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/groupRoleManagementPolicy",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/groupRoleManagementPolicy:GroupRoleManagementPolicy": "GroupRoleManagementPolicy"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/invitation",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/invitation:Invitation": "Invitation"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/namedLocation",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/namedLocation:NamedLocation": "NamedLocation"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/privilegedAccessGroupAssignmentSchedule",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/privilegedAccessGroupAssignmentSchedule:PrivilegedAccessGroupAssignmentSchedule": "PrivilegedAccessGroupAssignmentSchedule"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/privilegedAccessGroupEligibilitySchedule",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/privilegedAccessGroupEligibilitySchedule:PrivilegedAccessGroupEligibilitySchedule": "PrivilegedAccessGroupEligibilitySchedule"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/servicePrincipal",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/servicePrincipal:ServicePrincipal": "ServicePrincipal"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/servicePrincipalCertificate",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/servicePrincipalCertificate:ServicePrincipalCertificate": "ServicePrincipalCertificate"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/servicePrincipalClaimsMappingPolicyAssignment",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/servicePrincipalClaimsMappingPolicyAssignment:ServicePrincipalClaimsMappingPolicyAssignment": "ServicePrincipalClaimsMappingPolicyAssignment"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/servicePrincipalDelegatedPermissionGrant",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/servicePrincipalDelegatedPermissionGrant:ServicePrincipalDelegatedPermissionGrant": "ServicePrincipalDelegatedPermissionGrant"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/servicePrincipalPassword",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/servicePrincipalPassword:ServicePrincipalPassword": "ServicePrincipalPassword"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/servicePrincipalTokenSigningCertificate",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/servicePrincipalTokenSigningCertificate:ServicePrincipalTokenSigningCertificate": "ServicePrincipalTokenSigningCertificate"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/synchronizationJob",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/synchronizationJob:SynchronizationJob": "SynchronizationJob"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/synchronizationJobProvisionOnDemand",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/synchronizationJobProvisionOnDemand:SynchronizationJobProvisionOnDemand": "SynchronizationJobProvisionOnDemand"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/synchronizationSecret",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/synchronizationSecret:SynchronizationSecret": "SynchronizationSecret"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/user",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/user:User": "User"
  }
 },
 {
  "pkg": "azuread",
  "mod": "index/userFlowAttribute",
  "fqn": "pulumi_azuread",
  "classes": {
   "azuread:index/userFlowAttribute:UserFlowAttribute": "UserFlowAttribute"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "azuread",
  "token": "pulumi:providers:azuread",
  "fqn": "pulumi_azuread",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ApplicationOwnerArgs', 'ApplicationOwner']

@pulumi.input_type
class ApplicationOwnerArgs:
    def __init__(__self__, *,
                 application_id: pulumi.Input[str],
                 owner_object_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ApplicationOwner resource.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] owner_object_id: The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "application_id", application_id)
        pulumi.set(__self__, "owner_object_id", owner_object_id)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Input[str]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter(name="ownerObjectId")
    def owner_object_id(self) -> pulumi.Input[str]:
        """
        The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "owner_object_id")

    @owner_object_id.setter
    def owner_object_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "owner_object_id", value)


@pulumi.input_type
class _ApplicationOwnerState:
    def __init__(__self__, *,
                 application_id: Optional[pulumi.Input[str]] = None,
                 owner_object_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ApplicationOwner resources.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] owner_object_id: The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if owner_object_id is not None:
            pulumi.set(__self__, "owner_object_id", owner_object_id)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter(name="ownerObjectId")
    def owner_object_id(self) -> Optional[pulumi.Input[str]]:
        """
        The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "owner_object_id")

    @owner_object_id.setter
    def owner_object_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_object_id", value)


class ApplicationOwner(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 owner_object_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.ApplicationRegistration("example", display_name="example")
        jane = azuread.User("jane",
            user_principal_name="jane.fischer@example.com",
            display_name="Jane Fischer",
            password="Ch@ngeMe")
        example_jane = azuread.ApplicationOwner("example_jane",
            application_id=example.id,
            owner_object_id=jane.object_id)
        ```

        > **Tip** For managing more application owners, create additional instances of this resource

        ## Import

        Application Owners can be imported using the object ID of the application and the object ID of the owner, in the following format.

        ```sh
        $ pulumi import azuread:index/applicationOwner:ApplicationOwner example /applications/00000000-0000-0000-0000-000000000000/owners/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] owner_object_id: The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationOwnerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.ApplicationRegistration("example", display_name="example")
        jane = azuread.User("jane",
            user_principal_name="jane.fischer@example.com",
            display_name="Jane Fischer",
            password="Ch@ngeMe")
        example_jane = azuread.ApplicationOwner("example_jane",
            application_id=example.id,
            owner_object_id=jane.object_id)
        ```

        > **Tip** For managing more application owners, create additional instances of this resource

        ## Import

        Application Owners can be imported using the object ID of the application and the object ID of the owner, in the following format.

        ```sh
        $ pulumi import azuread:index/applicationOwner:ApplicationOwner example /applications/00000000-0000-0000-0000-000000000000/owners/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationOwnerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationOwnerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 owner_object_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationOwnerArgs.__new__(ApplicationOwnerArgs)

            if application_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_id'")
            __props__.__dict__["application_id"] = application_id
            if owner_object_id is None and not opts.urn:
                raise TypeError("Missing required property 'owner_object_id'")
            __props__.__dict__["owner_object_id"] = owner_object_id
        super(ApplicationOwner, __self__).__init__(
            'azuread:index/applicationOwner:ApplicationOwner',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_id: Optional[pulumi.Input[str]] = None,
            owner_object_id: Optional[pulumi.Input[str]] = None) -> 'ApplicationOwner':
        """
        Get an existing ApplicationOwner resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] owner_object_id: The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationOwnerState.__new__(_ApplicationOwnerState)

        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["owner_object_id"] = owner_object_id
        return ApplicationOwner(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[str]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter(name="ownerObjectId")
    def owner_object_id(self) -> pulumi.Output[str]:
        """
        The object ID of the owner to assign to the application, typically a user or service principal. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "owner_object_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetGroupRoleManagementPolicyResult',
    'AwaitableGetGroupRoleManagementPolicyResult',
    'get_group_role_management_policy',
    'get_group_role_management_policy_output',
]

@pulumi.output_type
class GetGroupRoleManagementPolicyResult:
    """
    A collection of values returned by getGroupRoleManagementPolicy.
    """
    def __init__(__self__, description=None, display_name=None, group_id=None, id=None, role_id=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if role_id and not isinstance(role_id, str):
            raise TypeError("Expected argument 'role_id' to be a str")
        pulumi.set(__self__, "role_id", role_id)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        (String) The description of this policy.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        (String) The display name of this policy.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> str:
        return pulumi.get(self, "role_id")


class AwaitableGetGroupRoleManagementPolicyResult(GetGroupRoleManagementPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupRoleManagementPolicyResult(
            description=self.description,
            display_name=self.display_name,
            group_id=self.group_id,
            id=self.id,
            role_id=self.role_id)


def get_group_role_management_policy(group_id: Optional[str] = None,
                                     role_id: Optional[str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupRoleManagementPolicyResult:
    """
    Use this data source to retrieve a role policy for an Azure AD group.

    ## API Permissions

    The following API permissions are required in order to use this resource.

    When authenticated with a service principal, this resource requires the `RoleManagementPolicy.Read.AzureADGroup` Microsoft Graph API permissions.

    When authenticated with a user principal, this resource requires `Global Administrator` directory role, or the `Privileged Role Administrator` role in Identity Governance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azuread as azuread

    example = azuread.Group("example",
        display_name="group-name",
        security_enabled=True)
    owners_policy = azuread.get_group_role_management_policy_output(group_id=example.id,
        role_id="owner")
    ```


    :param str group_id: The ID of the Azure AD group for which the policy applies.
    :param str role_id: The type of assignment this policy coveres. Can be either `member` or `owner`.
    """
    __args__ = dict()
    __args__['groupId'] = group_id
    __args__['roleId'] = role_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azuread:index/getGroupRoleManagementPolicy:getGroupRoleManagementPolicy', __args__, opts=opts, typ=GetGroupRoleManagementPolicyResult).value

    return AwaitableGetGroupRoleManagementPolicyResult(
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        role_id=pulumi.get(__ret__, 'role_id'))
def get_group_role_management_policy_output(group_id: Optional[pulumi.Input[str]] = None,
                                            role_id: Optional[pulumi.Input[str]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupRoleManagementPolicyResult]:
    """
    Use this data source to retrieve a role policy for an Azure AD group.

    ## API Permissions

    The following API permissions are required in order to use this resource.

    When authenticated with a service principal, this resource requires the `RoleManagementPolicy.Read.AzureADGroup` Microsoft Graph API permissions.

    When authenticated with a user principal, this resource requires `Global Administrator` directory role, or the `Privileged Role Administrator` role in Identity Governance.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azuread as azuread

    example = azuread.Group("example",
        display_name="group-name",
        security_enabled=True)
    owners_policy = azuread.get_group_role_management_policy_output(group_id=example.id,
        role_id="owner")
    ```


    :param str group_id: The ID of the Azure AD group for which the policy applies.
    :param str role_id: The type of assignment this policy coveres. Can be either `member` or `owner`.
    """
    __args__ = dict()
    __args__['groupId'] = group_id
    __args__['roleId'] = role_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azuread:index/getGroupRoleManagementPolicy:getGroupRoleManagementPolicy', __args__, opts=opts, typ=GetGroupRoleManagementPolicyResult)
    return __ret__.apply(lambda __response__: GetGroupRoleManagementPolicyResult(
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        role_id=pulumi.get(__response__, 'role_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SynchronizationJobProvisionOnDemandArgs', 'SynchronizationJobProvisionOnDemand']

@pulumi.input_type
class SynchronizationJobProvisionOnDemandArgs:
    def __init__(__self__, *,
                 parameters: pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]],
                 service_principal_id: pulumi.Input[str],
                 synchronization_job_id: pulumi.Input[str],
                 triggers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a SynchronizationJobProvisionOnDemand resource.
        :param pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]] parameters: One or more `parameter` blocks as documented below.
        :param pulumi.Input[str] service_principal_id: The ID of the service principal for the synchronization job.
        :param pulumi.Input[str] synchronization_job_id: The ID of the synchronization job.
        """
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "service_principal_id", service_principal_id)
        pulumi.set(__self__, "synchronization_job_id", synchronization_job_id)
        if triggers is not None:
            pulumi.set(__self__, "triggers", triggers)

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]]:
        """
        One or more `parameter` blocks as documented below.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Input[str]:
        """
        The ID of the service principal for the synchronization job.
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_principal_id", value)

    @property
    @pulumi.getter(name="synchronizationJobId")
    def synchronization_job_id(self) -> pulumi.Input[str]:
        """
        The ID of the synchronization job.
        """
        return pulumi.get(self, "synchronization_job_id")

    @synchronization_job_id.setter
    def synchronization_job_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "synchronization_job_id", value)

    @property
    @pulumi.getter
    def triggers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        return pulumi.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "triggers", value)


@pulumi.input_type
class _SynchronizationJobProvisionOnDemandState:
    def __init__(__self__, *,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]]] = None,
                 service_principal_id: Optional[pulumi.Input[str]] = None,
                 synchronization_job_id: Optional[pulumi.Input[str]] = None,
                 triggers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering SynchronizationJobProvisionOnDemand resources.
        :param pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]] parameters: One or more `parameter` blocks as documented below.
        :param pulumi.Input[str] service_principal_id: The ID of the service principal for the synchronization job.
        :param pulumi.Input[str] synchronization_job_id: The ID of the synchronization job.
        """
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)
        if synchronization_job_id is not None:
            pulumi.set(__self__, "synchronization_job_id", synchronization_job_id)
        if triggers is not None:
            pulumi.set(__self__, "triggers", triggers)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]]]:
        """
        One or more `parameter` blocks as documented below.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SynchronizationJobProvisionOnDemandParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the service principal for the synchronization job.
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_principal_id", value)

    @property
    @pulumi.getter(name="synchronizationJobId")
    def synchronization_job_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the synchronization job.
        """
        return pulumi.get(self, "synchronization_job_id")

    @synchronization_job_id.setter
    def synchronization_job_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "synchronization_job_id", value)

    @property
    @pulumi.getter
    def triggers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        return pulumi.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "triggers", value)


class SynchronizationJobProvisionOnDemand(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SynchronizationJobProvisionOnDemandParameterArgs', 'SynchronizationJobProvisionOnDemandParameterArgsDict']]]]] = None,
                 service_principal_id: Optional[pulumi.Input[str]] = None,
                 synchronization_job_id: Optional[pulumi.Input[str]] = None,
                 triggers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Manages synchronization job on demand provisioning associated with a service principal (enterprise application) within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires one of the following application roles: `Synchronization.ReadWrite.All`

        ## Example Usage

        *Basic example*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        current = azuread.get_client_config()
        example_group = azuread.Group("example",
            display_name="example",
            owners=[current.object_id],
            security_enabled=True)
        example = azuread.get_application_template(display_name="Azure Databricks SCIM Provisioning Connector")
        example_application_from_template = azuread.ApplicationFromTemplate("example",
            display_name="example",
            template_id=example.template_id)
        example_get_service_principal = azuread.get_service_principal_output(object_id=example_application_from_template.service_principal_object_id)
        example_synchronization_secret = azuread.SynchronizationSecret("example",
            service_principal_id=example_get_service_principal.id,
            credentials=[
                {
                    "key": "BaseAddress",
                    "value": "https://adb-example.azuredatabricks.net/api/2.0/preview/scim",
                },
                {
                    "key": "SecretToken",
                    "value": "some-token",
                },
            ])
        example_synchronization_job = azuread.SynchronizationJob("example",
            service_principal_id=example_get_service_principal.id,
            template_id="dataBricks",
            enabled=True)
        example_synchronization_job_provision_on_demand = azuread.SynchronizationJobProvisionOnDemand("example",
            service_principal_id=example_synchronization_job.service_principal_id,
            synchronization_job_id=example_synchronization_job.id,
            parameters=[{
                "rule_id": "",
                "subjects": [{
                    "object_id": example_group.object_id,
                    "object_type_name": "Group",
                }],
            }])
        ```

        ## Import

        This resource does not support importing.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SynchronizationJobProvisionOnDemandParameterArgs', 'SynchronizationJobProvisionOnDemandParameterArgsDict']]]] parameters: One or more `parameter` blocks as documented below.
        :param pulumi.Input[str] service_principal_id: The ID of the service principal for the synchronization job.
        :param pulumi.Input[str] synchronization_job_id: The ID of the synchronization job.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SynchronizationJobProvisionOnDemandArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages synchronization job on demand provisioning associated with a service principal (enterprise application) within Azure Active Directory.

        ## API Permissions

        The following API permissions are required in order to use this resource.

        When authenticated with a service principal, this resource requires one of the following application roles: `Synchronization.ReadWrite.All`

        ## Example Usage

        *Basic example*

        ```python
        import pulumi
        import pulumi_azuread as azuread

        current = azuread.get_client_config()
        example_group = azuread.Group("example",
            display_name="example",
            owners=[current.object_id],
            security_enabled=True)
        example = azuread.get_application_template(display_name="Azure Databricks SCIM Provisioning Connector")
        example_application_from_template = azuread.ApplicationFromTemplate("example",
            display_name="example",
            template_id=example.template_id)
        example_get_service_principal = azuread.get_service_principal_output(object_id=example_application_from_template.service_principal_object_id)
        example_synchronization_secret = azuread.SynchronizationSecret("example",
            service_principal_id=example_get_service_principal.id,
            credentials=[
                {
                    "key": "BaseAddress",
                    "value": "https://adb-example.azuredatabricks.net/api/2.0/preview/scim",
                },
                {
                    "key": "SecretToken",
                    "value": "some-token",
                },
            ])
        example_synchronization_job = azuread.SynchronizationJob("example",
            service_principal_id=example_get_service_principal.id,
            template_id="dataBricks",
            enabled=True)
        example_synchronization_job_provision_on_demand = azuread.SynchronizationJobProvisionOnDemand("example",
            service_principal_id=example_synchronization_job.service_principal_id,
            synchronization_job_id=example_synchronization_job.id,
            parameters=[{
                "rule_id": "",
                "subjects": [{
                    "object_id": example_group.object_id,
                    "object_type_name": "Group",
                }],
            }])
        ```

        ## Import

        This resource does not support importing.

        :param str resource_name: The name of the resource.
        :param SynchronizationJobProvisionOnDemandArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SynchronizationJobProvisionOnDemandArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SynchronizationJobProvisionOnDemandParameterArgs', 'SynchronizationJobProvisionOnDemandParameterArgsDict']]]]] = None,
                 service_principal_id: Optional[pulumi.Input[str]] = None,
                 synchronization_job_id: Optional[pulumi.Input[str]] = None,
                 triggers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SynchronizationJobProvisionOnDemandArgs.__new__(SynchronizationJobProvisionOnDemandArgs)

            if parameters is None and not opts.urn:
                raise TypeError("Missing required property 'parameters'")
            __props__.__dict__["parameters"] = parameters
            if service_principal_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_principal_id'")
            __props__.__dict__["service_principal_id"] = service_principal_id
            if synchronization_job_id is None and not opts.urn:
                raise TypeError("Missing required property 'synchronization_job_id'")
            __props__.__dict__["synchronization_job_id"] = synchronization_job_id
            __props__.__dict__["triggers"] = triggers
        super(SynchronizationJobProvisionOnDemand, __self__).__init__(
            'azuread:index/synchronizationJobProvisionOnDemand:SynchronizationJobProvisionOnDemand',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SynchronizationJobProvisionOnDemandParameterArgs', 'SynchronizationJobProvisionOnDemandParameterArgsDict']]]]] = None,
            service_principal_id: Optional[pulumi.Input[str]] = None,
            synchronization_job_id: Optional[pulumi.Input[str]] = None,
            triggers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'SynchronizationJobProvisionOnDemand':
        """
        Get an existing SynchronizationJobProvisionOnDemand resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['SynchronizationJobProvisionOnDemandParameterArgs', 'SynchronizationJobProvisionOnDemandParameterArgsDict']]]] parameters: One or more `parameter` blocks as documented below.
        :param pulumi.Input[str] service_principal_id: The ID of the service principal for the synchronization job.
        :param pulumi.Input[str] synchronization_job_id: The ID of the synchronization job.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SynchronizationJobProvisionOnDemandState.__new__(_SynchronizationJobProvisionOnDemandState)

        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["service_principal_id"] = service_principal_id
        __props__.__dict__["synchronization_job_id"] = synchronization_job_id
        __props__.__dict__["triggers"] = triggers
        return SynchronizationJobProvisionOnDemand(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Sequence['outputs.SynchronizationJobProvisionOnDemandParameter']]:
        """
        One or more `parameter` blocks as documented below.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Output[str]:
        """
        The ID of the service principal for the synchronization job.
        """
        return pulumi.get(self, "service_principal_id")

    @property
    @pulumi.getter(name="synchronizationJobId")
    def synchronization_job_id(self) -> pulumi.Output[str]:
        """
        The ID of the synchronization job.
        """
        return pulumi.get(self, "synchronization_job_id")

    @property
    @pulumi.getter
    def triggers(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        return pulumi.get(self, "triggers")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApplicationOptionalClaimsInitArgs', 'ApplicationOptionalClaims']

@pulumi.input_type
class ApplicationOptionalClaimsInitArgs:
    def __init__(__self__, *,
                 application_id: pulumi.Input[str],
                 access_tokens: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]]] = None,
                 id_tokens: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]]] = None,
                 saml2_tokens: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]]] = None):
        """
        The set of arguments for constructing a ApplicationOptionalClaims resource.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]] access_tokens: One or more `access_token` blocks as documented below.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]] id_tokens: One or more `id_token` blocks as documented below.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]] saml2_tokens: One or more `saml2_token` blocks as documented below.
               
               > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        pulumi.set(__self__, "application_id", application_id)
        if access_tokens is not None:
            pulumi.set(__self__, "access_tokens", access_tokens)
        if id_tokens is not None:
            pulumi.set(__self__, "id_tokens", id_tokens)
        if saml2_tokens is not None:
            pulumi.set(__self__, "saml2_tokens", saml2_tokens)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Input[str]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter(name="accessTokens")
    def access_tokens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]]]:
        """
        One or more `access_token` blocks as documented below.
        """
        return pulumi.get(self, "access_tokens")

    @access_tokens.setter
    def access_tokens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]]]):
        pulumi.set(self, "access_tokens", value)

    @property
    @pulumi.getter(name="idTokens")
    def id_tokens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]]]:
        """
        One or more `id_token` blocks as documented below.
        """
        return pulumi.get(self, "id_tokens")

    @id_tokens.setter
    def id_tokens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]]]):
        pulumi.set(self, "id_tokens", value)

    @property
    @pulumi.getter(name="saml2Tokens")
    def saml2_tokens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]]]:
        """
        One or more `saml2_token` blocks as documented below.

        > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        return pulumi.get(self, "saml2_tokens")

    @saml2_tokens.setter
    def saml2_tokens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]]]):
        pulumi.set(self, "saml2_tokens", value)


@pulumi.input_type
class _ApplicationOptionalClaimsState:
    def __init__(__self__, *,
                 access_tokens: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]]] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 id_tokens: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]]] = None,
                 saml2_tokens: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]]] = None):
        """
        Input properties used for looking up and filtering ApplicationOptionalClaims resources.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]] access_tokens: One or more `access_token` blocks as documented below.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]] id_tokens: One or more `id_token` blocks as documented below.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]] saml2_tokens: One or more `saml2_token` blocks as documented below.
               
               > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        if access_tokens is not None:
            pulumi.set(__self__, "access_tokens", access_tokens)
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if id_tokens is not None:
            pulumi.set(__self__, "id_tokens", id_tokens)
        if saml2_tokens is not None:
            pulumi.set(__self__, "saml2_tokens", saml2_tokens)

    @property
    @pulumi.getter(name="accessTokens")
    def access_tokens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]]]:
        """
        One or more `access_token` blocks as documented below.
        """
        return pulumi.get(self, "access_tokens")

    @access_tokens.setter
    def access_tokens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsAccessTokenArgs']]]]):
        pulumi.set(self, "access_tokens", value)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter(name="idTokens")
    def id_tokens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]]]:
        """
        One or more `id_token` blocks as documented below.
        """
        return pulumi.get(self, "id_tokens")

    @id_tokens.setter
    def id_tokens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsIdTokenArgs']]]]):
        pulumi.set(self, "id_tokens", value)

    @property
    @pulumi.getter(name="saml2Tokens")
    def saml2_tokens(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]]]:
        """
        One or more `saml2_token` blocks as documented below.

        > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        return pulumi.get(self, "saml2_tokens")

    @saml2_tokens.setter
    def saml2_tokens(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationOptionalClaimsSaml2TokenArgs']]]]):
        pulumi.set(self, "saml2_tokens", value)


class ApplicationOptionalClaims(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsAccessTokenArgs', 'ApplicationOptionalClaimsAccessTokenArgsDict']]]]] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 id_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsIdTokenArgs', 'ApplicationOptionalClaimsIdTokenArgsDict']]]]] = None,
                 saml2_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsSaml2TokenArgs', 'ApplicationOptionalClaimsSaml2TokenArgsDict']]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.ApplicationRegistration("example", display_name="example")
        example_application_optional_claims = azuread.ApplicationOptionalClaims("example",
            application_id=example.id,
            access_tokens=[
                {
                    "name": "myclaim",
                },
                {
                    "name": "otherclaim",
                },
            ],
            id_tokens=[{
                "name": "userclaim",
                "source": "user",
                "essential": True,
                "additional_properties": ["emit_as_roles"],
            }],
            saml2_tokens=[{
                "name": "samlexample",
            }])
        ```

        ## Import

        Application Optional Claims can be imported using the object ID of the application, in the following format.

        ```sh
        $ pulumi import azuread:index/applicationOptionalClaims:ApplicationOptionalClaims example /applications/00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsAccessTokenArgs', 'ApplicationOptionalClaimsAccessTokenArgsDict']]]] access_tokens: One or more `access_token` blocks as documented below.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsIdTokenArgs', 'ApplicationOptionalClaimsIdTokenArgsDict']]]] id_tokens: One or more `id_token` blocks as documented below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsSaml2TokenArgs', 'ApplicationOptionalClaimsSaml2TokenArgsDict']]]] saml2_tokens: One or more `saml2_token` blocks as documented below.
               
               > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationOptionalClaimsInitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_azuread as azuread

        example = azuread.ApplicationRegistration("example", display_name="example")
        example_application_optional_claims = azuread.ApplicationOptionalClaims("example",
            application_id=example.id,
            access_tokens=[
                {
                    "name": "myclaim",
                },
                {
                    "name": "otherclaim",
                },
            ],
            id_tokens=[{
                "name": "userclaim",
                "source": "user",
                "essential": True,
                "additional_properties": ["emit_as_roles"],
            }],
            saml2_tokens=[{
                "name": "samlexample",
            }])
        ```

        ## Import

        Application Optional Claims can be imported using the object ID of the application, in the following format.

        ```sh
        $ pulumi import azuread:index/applicationOptionalClaims:ApplicationOptionalClaims example /applications/00000000-0000-0000-0000-000000000000
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationOptionalClaimsInitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationOptionalClaimsInitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsAccessTokenArgs', 'ApplicationOptionalClaimsAccessTokenArgsDict']]]]] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 id_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsIdTokenArgs', 'ApplicationOptionalClaimsIdTokenArgsDict']]]]] = None,
                 saml2_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsSaml2TokenArgs', 'ApplicationOptionalClaimsSaml2TokenArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationOptionalClaimsInitArgs.__new__(ApplicationOptionalClaimsInitArgs)

            __props__.__dict__["access_tokens"] = access_tokens
            if application_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_id'")
            __props__.__dict__["application_id"] = application_id
            __props__.__dict__["id_tokens"] = id_tokens
            __props__.__dict__["saml2_tokens"] = saml2_tokens
        super(ApplicationOptionalClaims, __self__).__init__(
            'azuread:index/applicationOptionalClaims:ApplicationOptionalClaims',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsAccessTokenArgs', 'ApplicationOptionalClaimsAccessTokenArgsDict']]]]] = None,
            application_id: Optional[pulumi.Input[str]] = None,
            id_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsIdTokenArgs', 'ApplicationOptionalClaimsIdTokenArgsDict']]]]] = None,
            saml2_tokens: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsSaml2TokenArgs', 'ApplicationOptionalClaimsSaml2TokenArgsDict']]]]] = None) -> 'ApplicationOptionalClaims':
        """
        Get an existing ApplicationOptionalClaims resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsAccessTokenArgs', 'ApplicationOptionalClaimsAccessTokenArgsDict']]]] access_tokens: One or more `access_token` blocks as documented below.
        :param pulumi.Input[str] application_id: The resource ID of the application registration. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsIdTokenArgs', 'ApplicationOptionalClaimsIdTokenArgsDict']]]] id_tokens: One or more `id_token` blocks as documented below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationOptionalClaimsSaml2TokenArgs', 'ApplicationOptionalClaimsSaml2TokenArgsDict']]]] saml2_tokens: One or more `saml2_token` blocks as documented below.
               
               > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationOptionalClaimsState.__new__(_ApplicationOptionalClaimsState)

        __props__.__dict__["access_tokens"] = access_tokens
        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["id_tokens"] = id_tokens
        __props__.__dict__["saml2_tokens"] = saml2_tokens
        return ApplicationOptionalClaims(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessTokens")
    def access_tokens(self) -> pulumi.Output[Optional[Sequence['outputs.ApplicationOptionalClaimsAccessToken']]]:
        """
        One or more `access_token` blocks as documented below.
        """
        return pulumi.get(self, "access_tokens")

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[str]:
        """
        The resource ID of the application registration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter(name="idTokens")
    def id_tokens(self) -> pulumi.Output[Optional[Sequence['outputs.ApplicationOptionalClaimsIdToken']]]:
        """
        One or more `id_token` blocks as documented below.
        """
        return pulumi.get(self, "id_tokens")

    @property
    @pulumi.getter(name="saml2Tokens")
    def saml2_tokens(self) -> pulumi.Output[Optional[Sequence['outputs.ApplicationOptionalClaimsSaml2Token']]]:
        """
        One or more `saml2_token` blocks as documented below.

        > At least one of `access_token`, `id_token` or `saml2_token` must be specified
        """
        return pulumi.get(self, "saml2_tokens")

